@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use 5.008;
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
 $VERSION = eval $VERSION;
 
 
@@ -88,7 +88,7 @@ Data::HandyGen::mysql - Generates test data for mysql easily.
 
 =head1 VERSION
 
-This documentation refers to Data::HandyGen::mysql version 0.0.1
+This documentation refers to Data::HandyGen::mysql version 0.0.2
 
 
 =head1 SYNOPSIS
@@ -1112,7 +1112,7 @@ sub _add_record_if_not_exist {
     my ($self, $table, $col, $value) = @_;
 
     if ( 0 == $self->_value_exists_in_table_col($table, $col, $value) ) {     #  No record exists
-        $self->process_table($table, { $col => $value });       #  レコード作成
+        $self->process_table($table, { $col => $value });
         $self->_print_debug("A referenced record created. id = $value");
     }
 }
